@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "Engine.h"
 
 #include "libboardgame_sys/CpuTime.h"
@@ -32,7 +28,7 @@ Engine::Engine()
 void Engine::cmd_cputime(Response& response)
 {
     double time = libboardgame_sys::cpu_time();
-    if (time == -1)
+    if (time < 0)
         throw Failure("cannot determine cpu time");
     response << time;
 }
