@@ -21,16 +21,13 @@ template<class P>
 class PointTransform
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    virtual ~PointTransform();
+    virtual ~PointTransform() = default;
 
-    virtual Point get_transformed(const Point& p,
-                                  const Geometry<P>& geo) const = 0;
+    virtual Point get_transformed(Point p, const Geometry<P>& geo) const = 0;
 };
 
-template<class P>
-PointTransform<P>::~PointTransform() = default;
 
 //-----------------------------------------------------------------------------
 
@@ -39,15 +36,14 @@ class PointTransfIdent
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfIdent<P>::get_transformed(const Point& p,
-                                       const Geometry<P>& geo) const
+P PointTransfIdent<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     LIBBOARDGAME_UNUSED(geo);
     return p;
@@ -61,15 +57,14 @@ class PointTransfRot90
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfRot90<P>::get_transformed(const Point& p,
-                                       const Geometry<P>& geo) const
+P PointTransfRot90<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     unsigned x = geo.get_width() - geo.get_y(p) - 1;
     unsigned y = geo.get_x(p);
@@ -84,15 +79,14 @@ class PointTransfRot180
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfRot180<P>::get_transformed(const Point& p,
-                                        const Geometry<P>& geo) const
+P PointTransfRot180<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     unsigned x = geo.get_width() - geo.get_x(p) - 1;
     unsigned y = geo.get_height() - geo.get_y(p) - 1;
@@ -107,15 +101,14 @@ class PointTransfRot270
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfRot270<P>::get_transformed(const Point& p,
-                                        const Geometry<P>& geo) const
+P PointTransfRot270<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     unsigned x = geo.get_y(p);
     unsigned y = geo.get_height() - geo.get_x(p) - 1;
@@ -131,15 +124,14 @@ class PointTransfRot270Refl
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfRot270Refl<P>::get_transformed(const Point& p,
-                                            const Geometry<P>& geo) const
+P PointTransfRot270Refl<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     return geo.get_point(geo.get_y(p), geo.get_x(p));
 }
@@ -153,15 +145,14 @@ class PointTransfRot90Refl
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfRot90Refl<P>::get_transformed(const Point& p,
-                                           const Geometry<P>& geo) const
+P PointTransfRot90Refl<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     unsigned x = geo.get_width() - geo.get_y(p) - 1;
     unsigned y = geo.get_height() - geo.get_x(p) - 1;
@@ -176,15 +167,14 @@ class PointTransfRefl
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfRefl<P>::get_transformed(const Point& p,
-                                      const Geometry<P>& geo) const
+P PointTransfRefl<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     unsigned x = geo.get_width() - geo.get_x(p) - 1;
     unsigned y = geo.get_y(p);
@@ -199,15 +189,14 @@ class PointTransfReflRot180
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfReflRot180<P>::get_transformed(const Point& p,
-                                            const Geometry<P>& geo) const
+P PointTransfReflRot180<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     unsigned x = geo.get_x(p);
     unsigned y = geo.get_height() - geo.get_y(p) - 1;
@@ -221,22 +210,21 @@ class PointTransfTrigonRot60
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfTrigonRot60<P>::get_transformed(const Point& p,
-                                             const Geometry<P>& geo) const
+P PointTransfTrigonRot60<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     float cx = 0.5f * static_cast<float>(geo.get_width() - 1);
     float cy = 0.5f * static_cast<float>(geo.get_height() - 1);
     float px = static_cast<float>(geo.get_x(p)) - cx;
     float py = static_cast<float>(geo.get_y(p)) - cy;
-    unsigned x = static_cast<unsigned>(round(cx + 0.5f * px + 1.5f * py));
-    unsigned y = static_cast<unsigned>(round(cy - 0.5f * px + 0.5f * py));
+    auto x = static_cast<unsigned>(round(cx + 0.5f * px + 1.5f * py));
+    auto y = static_cast<unsigned>(round(cy - 0.5f * px + 0.5f * py));
     return geo.get_point(x, y);
 }
 
@@ -247,22 +235,21 @@ class PointTransfTrigonRot120
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfTrigonRot120<P>::get_transformed(const Point& p,
-                                              const Geometry<P>& geo) const
+P PointTransfTrigonRot120<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     float cx = 0.5f * static_cast<float>(geo.get_width() - 1);
     float cy = 0.5f * static_cast<float>(geo.get_height() - 1);
     float px = static_cast<float>(geo.get_x(p)) - cx;
     float py = static_cast<float>(geo.get_y(p)) - cy;
-    unsigned x = static_cast<unsigned>(round(cx - 0.5f * px + 1.5f * py));
-    unsigned y = static_cast<unsigned>(round(cy - 0.5f * px - 0.5f * py));
+    auto x = static_cast<unsigned>(round(cx - 0.5f * px + 1.5f * py));
+    auto y = static_cast<unsigned>(round(cy - 0.5f * px - 0.5f * py));
     return geo.get_point(x, y);
 }
 
@@ -273,22 +260,21 @@ class PointTransfTrigonRot240
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfTrigonRot240<P>::get_transformed(const Point& p,
-                                              const Geometry<P>& geo) const
+P PointTransfTrigonRot240<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     float cx = 0.5f * static_cast<float>(geo.get_width() - 1);
     float cy = 0.5f * static_cast<float>(geo.get_height() - 1);
     float px = static_cast<float>(geo.get_x(p)) - cx;
     float py = static_cast<float>(geo.get_y(p)) - cy;
-    unsigned x = static_cast<unsigned>(round(cx - 0.5f * px - 1.5f * py));
-    unsigned y = static_cast<unsigned>(round(cy + 0.5f * px - 0.5f * py));
+    auto x = static_cast<unsigned>(round(cx - 0.5f * px - 1.5f * py));
+    auto y = static_cast<unsigned>(round(cy + 0.5f * px - 0.5f * py));
     return geo.get_point(x, y);
 }
 
@@ -299,22 +285,21 @@ class PointTransfTrigonRot300
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfTrigonRot300<P>::get_transformed(const Point& p,
-                                              const Geometry<P>& geo) const
+P PointTransfTrigonRot300<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     float cx = 0.5f * static_cast<float>(geo.get_width() - 1);
     float cy = 0.5f * static_cast<float>(geo.get_height() - 1);
     float px = static_cast<float>(geo.get_x(p)) - cx;
     float py = static_cast<float>(geo.get_y(p)) - cy;
-    unsigned x = static_cast<unsigned>(round(cx + 0.5f * px - 1.5f * py));
-    unsigned y = static_cast<unsigned>(round(cy + 0.5f * px + 0.5f * py));
+    auto x = static_cast<unsigned>(round(cx + 0.5f * px - 1.5f * py));
+    auto y = static_cast<unsigned>(round(cy + 0.5f * px + 0.5f * py));
     return geo.get_point(x, y);
 }
 
@@ -325,22 +310,21 @@ class PointTransfTrigonReflRot60
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfTrigonReflRot60<P>::get_transformed(const Point& p,
-                                                 const Geometry<P>& geo) const
+P PointTransfTrigonReflRot60<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     float cx = 0.5f * static_cast<float>(geo.get_width() - 1);
     float cy = 0.5f * static_cast<float>(geo.get_height() - 1);
     float px = static_cast<float>(geo.get_x(p)) - cx;
     float py = static_cast<float>(geo.get_y(p)) - cy;
-    unsigned x = static_cast<unsigned>(round(cx + 0.5f * (-px) + 1.5f * py));
-    unsigned y = static_cast<unsigned>(round(cy - 0.5f * (-px) + 0.5f * py));
+    auto x = static_cast<unsigned>(round(cx + 0.5f * (-px) + 1.5f * py));
+    auto y = static_cast<unsigned>(round(cy - 0.5f * (-px) + 0.5f * py));
     return geo.get_point(x, y);
 }
 
@@ -351,22 +335,21 @@ class PointTransfTrigonReflRot120
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfTrigonReflRot120<P>::get_transformed(const Point& p,
-                                                  const Geometry<P>& geo) const
+P PointTransfTrigonReflRot120<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     float cx = 0.5f * static_cast<float>(geo.get_width() - 1);
     float cy = 0.5f * static_cast<float>(geo.get_height() - 1);
     float px = static_cast<float>(geo.get_x(p)) - cx;
     float py = static_cast<float>(geo.get_y(p)) - cy;
-    unsigned x = static_cast<unsigned>(round(cx - 0.5f * (-px) + 1.5f * py));
-    unsigned y = static_cast<unsigned>(round(cy - 0.5f * (-px) - 0.5f * py));
+    auto x = static_cast<unsigned>(round(cx - 0.5f * (-px) + 1.5f * py));
+    auto y = static_cast<unsigned>(round(cy - 0.5f * (-px) - 0.5f * py));
     return geo.get_point(x, y);
 }
 
@@ -377,22 +360,21 @@ class PointTransfTrigonReflRot240
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfTrigonReflRot240<P>::get_transformed(const Point& p,
-                                                  const Geometry<P>& geo) const
+P PointTransfTrigonReflRot240<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     float cx = 0.5f * static_cast<float>(geo.get_width() - 1);
     float cy = 0.5f * static_cast<float>(geo.get_height() - 1);
     float px = static_cast<float>(geo.get_x(p)) - cx;
     float py = static_cast<float>(geo.get_y(p)) - cy;
-    unsigned x = static_cast<unsigned>(round(cx - 0.5f * (-px) - 1.5f * py));
-    unsigned y = static_cast<unsigned>(round(cy + 0.5f * (-px) - 0.5f * py));
+    auto x = static_cast<unsigned>(round(cx - 0.5f * (-px) - 1.5f * py));
+    auto y = static_cast<unsigned>(round(cy + 0.5f * (-px) - 0.5f * py));
     return geo.get_point(x, y);
 }
 
@@ -403,22 +385,21 @@ class PointTransfTrigonReflRot300
     : public PointTransform<P>
 {
 public:
-    typedef P Point;
+    using Point = P;
 
-    Point get_transformed(const Point& p,
-                          const Geometry<P>& geo) const override;
+    Point get_transformed(Point p, const Geometry<P>& geo) const override;
 };
 
+
 template<class P>
-P PointTransfTrigonReflRot300<P>::get_transformed(const Point& p,
-                                                  const Geometry<P>& geo) const
+P PointTransfTrigonReflRot300<P>::get_transformed(Point p, const Geometry<P>& geo) const
 {
     float cx = 0.5f * static_cast<float>(geo.get_width() - 1);
     float cy = 0.5f * static_cast<float>(geo.get_height() - 1);
     float px = static_cast<float>(geo.get_x(p)) - cx;
     float py = static_cast<float>(geo.get_y(p)) - cy;
-    unsigned x = static_cast<unsigned>(round(cx + 0.5f * (-px) - 1.5f * py));
-    unsigned y = static_cast<unsigned>(round(cy + 0.5f * (-px) + 0.5f * py));
+    auto x = static_cast<unsigned>(round(cx + 0.5f * (-px) - 1.5f * py));
+    auto y = static_cast<unsigned>(round(cy + 0.5f * (-px) + 0.5f * py));
     return geo.get_point(x, y);
 }
 
