@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "Rating.h"
 
 #include <iostream>
@@ -17,7 +13,7 @@ namespace libboardgame_base {
 
 //-----------------------------------------------------------------------------
 
-ostream& operator<<(ostream& out, const Rating& rating)
+ostream& operator<<(ostream& out, Rating rating)
 {
     out << rating.m_elo;
     return out;
