@@ -4,13 +4,8 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "CmdLine.h"
 
-#include <cassert>
 #include <limits>
 #include <sstream>
 
@@ -80,7 +75,7 @@ CmdLineRange CmdLine::get_trimmed_line_after_elem(unsigned i) const
     auto end = m_line.end();
     while (end > begin && isspace(static_cast<unsigned char>(*(end - 1))) != 0)
         --end;
-    return CmdLineRange(begin, end);
+    return {begin, end};
 }
 
 void CmdLine::init(const string& line)
