@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "Engine.h"
 
 #include <cctype>
@@ -56,7 +52,6 @@ Engine::Engine()
 {
     add("known_command", &Engine::cmd_known_command);
     add("list_commands", &Engine::cmd_list_commands);
-    add("protocol_version", &Engine::cmd_protocol_version);
     add("quit", &Engine::cmd_quit);
 }
 
@@ -103,12 +98,6 @@ void Engine::cmd_list_commands(Response& response)
         response << i.first << '\n';
 }
 
-/** Return protocol version. */
-void Engine::cmd_protocol_version(Response& response)
-{
-    response.set("2");
-}
-
 /** Quit command loop. */
 void Engine::cmd_quit()
 {
