@@ -22,17 +22,18 @@
 #include "libboardgame_util/Barrier.h"
 #include "libboardgame_util/IntervalChecker.h"
 #include "libboardgame_util/Log.h"
-#include "libboardgame_util/MathUtil.h"
+#include "libboardgame_util/RandomGenerator.h"
 #include "libboardgame_util/Statistics.h"
 #include "libboardgame_util/StringUtil.h"
 #include "libboardgame_util/TimeIntervalChecker.h"
 #include "libboardgame_util/Timer.h"
 #include "libboardgame_util/Unused.h"
+#include "libboardgame_sys/Compiler.h"
 
 namespace libboardgame_mcts {
 
 using namespace std;
-using libboardgame_mcts::tree_util::find_node;
+using libboardgame_mcts::find_node;
 using libboardgame_util::get_abort;
 using libboardgame_util::time_to_string;
 using libboardgame_util::to_string;
@@ -257,13 +258,21 @@ public:
     Float get_exploration_constant() const { return m_exploration_constant; }
 
     /** Reuse the subtree from the previous search if the current position is
-        a follow-up position of the previous one. */
+        a follow-up position of the previous one.
+        It will also reuse the tree if it is the same position but the last
+        search was aborted. The default value is true, because this is
+        the usually preferred behavior during games to save search time.
+        @see set_reuse_tree() */
     void set_reuse_subtree(bool enable);
 
     bool get_reuse_subtree() const;
 
     /** Reuse the tree from the previous search if the current position is
-        the same position as the previous one. */
+        the same position as the previous one.
+        The default value is false, because the usually preferred behavior
+        is to see if the search generates different moves when doing subsequent
+        searches in the same position.
+        @see set_subreuse_tree() */
     void set_reuse_tree(bool enable);
 
     bool get_reuse_tree() const;
@@ -301,7 +310,7 @@ public:
 
     const Tree& get_tree() const;
 
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
     string dump() const;
 #endif
 
@@ -343,7 +352,7 @@ public:
         This cannot be done in the constructor because it uses the virtual
         function create_state(). This function will automatically be called
         before a search if the threads have not been constructed yet, but it
-        is advisable to explicitely call it in the constructor of the subclass
+        is advisable to explicitly call it in the constructor of the subclass
         to save some time at the first move generation where the game clock
         might already be running. */
     void create_threads();
@@ -361,7 +370,7 @@ protected:
     virtual void on_start_search(bool is_followup);
 
 private:
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
     class AssertionHandler
         : public libboardgame_util::AssertionHandler
     {
@@ -487,6 +496,8 @@ private:
     /** Time of last search. */
     double m_last_time;
 
+    bool m_last_aborted = false;
+
     Float m_rave_parent_max = 50000;
 
     Float m_rave_child_max = 2000;
@@ -516,7 +527,7 @@ private:
 
     Tree m_tmp_tree;
 
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
     AssertionHandler m_assertion_handler;
 #endif
 
@@ -627,7 +638,7 @@ void SearchBase<S, M, R>::Thread::wait_search_finished()
 }
 
 
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
 template<class S, class M, class R>
 SearchBase<S, M, R>::AssertionHandler::AssertionHandler(
         const SearchBase& search)
@@ -649,7 +660,7 @@ SearchBase<S, M, R>::SearchBase(unsigned nu_threads, size_t memory)
       m_nu_threads(nu_threads),
       m_exploration_constant(0),
       m_tmp_tree(memory / 2, m_nu_threads)
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
       , m_assertion_handler(*this)
 #endif
 { }
@@ -660,7 +671,7 @@ SearchBase<S, M, R>::~SearchBase() = default; // Non-inline to avoid GCC -Winlin
 template<class S, class M, class R>
 bool SearchBase<S, M, R>::check_abort(const ThreadState& thread_state) const
 {
-#if LIBBOARDGAME_DISABLE_LOG
+#ifdef LIBBOARDGAME_DISABLE_LOG
     LIBBOARDGAME_UNUSED(thread_state);
 #endif
     if (m_max_count > 0 && m_tree.get_root().get_visit_count() >= m_max_count)
@@ -728,7 +739,7 @@ template<class S, class M, class R>
 bool SearchBase<S, M, R>::check_cannot_change(ThreadState& thread_state,
                                               Float remaining) const
 {
-#if LIBBOARDGAME_DISABLE_LOG
+#ifdef LIBBOARDGAME_DISABLE_LOG
     LIBBOARDGAME_UNUSED(thread_state);
 #endif
     // select_final() selects move with highest number of wins.
@@ -800,7 +811,7 @@ void SearchBase<S, M, R>::create_threads()
     }
 }
 
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
 template<class S, class M, class R>
 string SearchBase<S, M, R>::dump() const
 {
@@ -1013,7 +1024,7 @@ bool SearchBase<S, M, R>::prune(TimeSource& time_source, double time,
                                 Float prune_min_count,
                                 Float& new_prune_min_count)
 {
-#if LIBBOARDGAME_DISABLE_LOG
+#ifdef LIBBOARDGAME_DISABLE_LOG
     LIBBOARDGAME_UNUSED(time);
 #endif
     Timer timer(time_source);
@@ -1094,13 +1105,14 @@ bool SearchBase<S, M, R>::search(Move& mv, Float max_count,
     else
         for (PlayerInt i = 0; i < m_nu_players; ++i)
             m_root_val[i].init(SearchParamConst::tie_value, 1);
-    if ((m_reuse_subtree && is_followup) || (m_reuse_tree && is_same))
+    if ((m_reuse_subtree && (is_followup || m_last_aborted))
+            || (m_reuse_tree && is_same))
     {
         size_t tree_nodes = m_tree.get_nu_nodes();
         if (m_followup_sequence.empty())
         {
             if (tree_nodes > 1)
-                LIBBOARDGAME_LOG("Reusing all ", tree_nodes, "nodes (count=",
+                LIBBOARDGAME_LOG("Reusing all ", tree_nodes, " nodes (count=",
                                  m_tree.get_root().get_visit_count(), ")");
         }
         else
@@ -1212,6 +1224,7 @@ bool SearchBase<S, M, R>::search(Move& mv, Float max_count,
     LIBBOARDGAME_LOG(get_info());
     bool result = select_move(mv);
     m_time_source = nullptr;
+    m_last_aborted = get_abort();
     return result;
 }
 
