@@ -93,7 +93,7 @@ public:
 
         const Node* m_best_child;
 
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
         Float m_child_min_count;
 
         Float m_max_move_prior;
@@ -191,7 +191,7 @@ inline Tree<N>::NodeExpander::NodeExpander(unsigned thread_id, Tree& tree,
       m_best_child(nullptr)
 {
     LIBBOARDGAME_ASSERT(thread_id < tree.m_nu_threads);
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
     m_child_min_count = child_min_count;
     m_max_move_prior = max_move_prior;
 #else
@@ -278,7 +278,13 @@ Tree<N>::Tree(size_t memory, unsigned nu_threads)
         min(max_nodes, static_cast<size_t>(numeric_limits<NodeIdx>::max()));
     m_nu_threads = nu_threads;
     m_max_nodes = max_nodes;
-    m_nodes = make_unique<Node[]>(max_nodes);
+
+    // Using make_unique<Node[]>(max_nodes) slows down the array creation and
+    // thereby the startup time of Pentobi with GCC 7/8 because the compiler
+    // does not optimize away the call to the empty Move() constructor (last
+    // tested with GCC 7.2.0 and GCC 8.0.0 on Ubuntu 17.10).
+    m_nodes.reset(new Node[max_nodes]);
+
     m_thread_storage = make_unique<ThreadStorage[]>(nu_threads);
     m_nodes_per_thread = max_nodes / nu_threads;
     for (unsigned i = 0; i < nu_threads; ++i)
