@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "Reader.h"
 
 #include <cctype>
@@ -100,10 +96,9 @@ bool Reader::read(istream& in, bool check_single_tree)
         {
             if (check_single_tree)
                 throw ReadError("Input has multiple game trees");
-            else
-                return true;
+            return true;
         }
-        else if (is_ascii_space(c))
+        if (is_ascii_space(c))
             m_in->get();
         else
             throw ReadError("Extra characters after end of tree.");
