@@ -4,21 +4,17 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "SgfTree.h"
 
 #include <ctime>
 #include <cstdio>
 #include <cstdlib>
-#include "libboardgame_sgf/SgfUtil.h"
+#include "SgfUtil.h"
 #include "libboardgame_util/StringUtil.h"
 
 namespace libboardgame_sgf {
 
-using libboardgame_sgf::util::find_root;
+using libboardgame_sgf::find_root;
 using libboardgame_util::trim;
 
 //-----------------------------------------------------------------------------
@@ -258,7 +254,6 @@ void SgfTree::set_interesting_move(const SgfNode& node)
 
 const SgfNode& SgfTree::truncate(const SgfNode& node)
 {
-    LIBBOARDGAME_ASSERT(node.has_parent());
     auto& parent = node.get_parent();
     non_const(parent).remove_child(non_const(node));
     m_modified = true;
