@@ -11,7 +11,6 @@
 #include "SgfTree.h"
 
 namespace libboardgame_sgf {
-namespace util {
 
 using namespace std;
 
@@ -39,9 +38,6 @@ void get_path_from_root(const SgfNode& node, vector<const SgfNode*>& path);
 
 const SgfNode& get_last_node(const SgfNode& node);
 
-/** Get a string representation of move annotation properties. */
-const char* get_move_annotation(const SgfTree& tree, const SgfNode& node);
-
 /** Get next node for iteration through complete tree. */
 const SgfNode* get_next_node(const SgfNode& node);
 
@@ -71,7 +67,6 @@ bool is_empty(const SgfTree& tree);
 
 //-----------------------------------------------------------------------------
 
-} // namespace util
 } // namespace libboardgame_sgf
 
 #endif // LIBBOARDGAME_SGF_SGF_UTIL_H
