@@ -4,18 +4,12 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "Abort.h"
 
 //----------------------------------------------------------------------------
 
 namespace libboardgame_util {
 
-using namespace std;
-
 atomic<bool> abort(false);
 
 //----------------------------------------------------------------------------
