@@ -18,20 +18,11 @@ using namespace std;
 
 extern atomic<bool> abort;
 
-inline void clear_abort()
-{
-    abort.store(false, memory_order_seq_cst);
-}
+inline void clear_abort() { abort = false; }
 
-inline bool get_abort()
-{
-    return abort.load(memory_order_relaxed);
-}
+inline bool get_abort() { return abort; }
 
-inline void set_abort()
-{
-    abort.store(true, memory_order_seq_cst);
-}
+inline void set_abort() { abort = true; }
 
 //-----------------------------------------------------------------------------
 
