@@ -7,8 +7,6 @@
 #ifndef LIBBOARDGAME_UTIL_BARRIER_H
 #define LIBBOARDGAME_UTIL_BARRIER_H
 
-#include "Assert.h"
-
 #include <condition_variable>
 #include <mutex>
 
@@ -35,7 +33,7 @@ private:
 
     unsigned m_count;
 
-    unsigned m_current;
+    unsigned m_current = 0;
 };
 
 //-----------------------------------------------------------------------------
