@@ -4,38 +4,21 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "IntervalChecker.h"
 
 #include <limits>
 #include "Assert.h"
-#if LIBBOARDGAME_UTIL_INTERVAL_CHECKER_DEBUG
-#include "Log.h"
-#endif
 
 namespace libboardgame_util {
 
 //-----------------------------------------------------------------------------
 
-#ifndef LIBBOARDGAME_UTIL_INTERVAL_CHECKER_DEBUG
-#define LIBBOARDGAME_UTIL_INTERVAL_CHECKER_DEBUG 0
-#endif
-
-//-----------------------------------------------------------------------------
-
 IntervalChecker::IntervalChecker(TimeSource& time_source, double time_interval,
                                  const function<bool()>& f)
     : m_time_source(time_source),
       m_time_interval(time_interval),
       m_function(f)
 {
-#if LIBBOARDGAME_UTIL_INTERVAL_CHECKER_DEBUG
-    log(format("IntervalChecker::IntervalChecker: time_interval=%1%")
-            % time_interval);
-#endif
     LIBBOARDGAME_ASSERT(time_interval > 0);
 }
 
@@ -73,17 +56,9 @@ bool IntervalChecker::check_expensive()
         else
             m_count_interval = static_cast<unsigned>(new_count_interval);
         m_result = m_function();
-#if LIBBOARDGAME_UTIL_INTERVAL_CHECKER_DEBUG
-        log(format("IntervalChecker::check_expensive: "
-                   "diff=%1% adjust_factor=%2% count_interval=%3%")
-            % diff % adjust_factor % m_count_interval);
-#endif
     }
     else
     {
-#if LIBBOARDGAME_UTIL_INTERVAL_CHECKER_DEBUG
-        log("IntervalChecker::check_expensive: is_first_check");
-#endif
         m_is_first_check = false;
     }
     m_last_time = time;
