@@ -4,14 +4,10 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#if ! LIBBOARDGAME_DISABLE_LOG
+#ifndef LIBBOARDGAME_DISABLE_LOG
 
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "Log.h"
 
 #include <iostream>
@@ -81,7 +77,7 @@ AndroidBuf android_buffer;
 
 //-----------------------------------------------------------------------------
 
-ostream* _log_stream = &cerr;
+ostream* _log_stream = nullptr;
 
 //-----------------------------------------------------------------------------
 
@@ -113,6 +109,7 @@ void _log_init()
 #if defined ANDROID || defined __ANDROID__
     cerr.rdbuf(&android_buffer);
 #endif
+    _log_stream = &cerr;
 }
 
 //-----------------------------------------------------------------------------
