@@ -11,7 +11,7 @@
 
 template<class T> static void LIBBOARDGAME_UNUSED(const T&) { }
 
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
 #define LIBBOARDGAME_UNUSED_IF_NOT_DEBUG(x)
 #else
 #define LIBBOARDGAME_UNUSED_IF_NOT_DEBUG(x) LIBBOARDGAME_UNUSED(x)
