@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "BoardUpdater.h"
 
 #include "BoardUtil.h"
@@ -17,8 +13,8 @@
 namespace libpentobi_base {
 
 using libboardgame_sgf::SgfError;
-using libboardgame_sgf::util::get_path_from_root;
-using libpentobi_base::boardutil::get_current_position_as_setup;
+using libboardgame_sgf::get_path_from_root;
+using libpentobi_base::get_current_position_as_setup;
 
 //-----------------------------------------------------------------------------
 
@@ -39,14 +35,8 @@ void handle_setup_property(const SgfNode& node, const char* id, Color c,
     for (auto& s : node.get_multi_property(id))
     {
         Move mv;
-        try
-        {
-            mv = bd.from_string(s);
-        }
-        catch (const runtime_error& e)
-        {
-            throw SgfError(e.what());
-        }
+        if (! bd.from_string(mv, s))
+            throw SgfError("invalid move " + s);
         Piece piece = bd.get_move_piece(mv);
         if (! pieces_left[c].remove(piece))
             throw SgfError("piece played twice");
@@ -63,25 +53,15 @@ void handle_setup_empty(const SgfNode& node, const Board& bd, Setup& setup,
     for (auto& s : node.get_multi_property("AE"))
     {
         Move mv;
-        try
-        {
-            mv = bd.from_string(s);
-        }
-        catch (const runtime_error& e)
-        {
-            throw SgfError(e.what());
-        }
+        if (! bd.from_string(mv, s))
+            throw SgfError("invalid move " + s);
         for (Color c : bd.get_colors())
-        {
             if (setup.placements[c].remove(mv))
             {
                 Piece piece = bd.get_move_piece(mv);
-                LIBBOARDGAME_ASSERT(! pieces_left[c].contains(piece));
                 pieces_left[c].push_back(piece);
                 break;
             }
-            throw SgfError("invalid value for AE property");
-        }
     }
 }
 
@@ -108,7 +88,7 @@ void init_setup(Board& bd, const SgfNode& node)
     handle_setup_property(node, "AW", Color(1), bd, setup, all_pieces_left);
     handle_setup_empty(node, bd, setup, all_pieces_left);
     Color to_play;
-    if (! libpentobi_base::node_util::get_player(node, bd.get_nu_colors(),
+    if (! libpentobi_base::get_player(node, bd.get_nu_colors(),
                                                  setup.to_play))
     {
         // Try to guess who should be to play based on the setup pieces.
@@ -135,7 +115,7 @@ void BoardUpdater::update(Board& bd, const PentobiTree& tree,
     get_path_from_root(node, m_path);
     for (const auto i : m_path)
     {
-        if (libpentobi_base::node_util::has_setup(*i))
+        if (libpentobi_base::has_setup(*i))
             init_setup(bd, *i);
         auto mv = tree.get_move(*i);
         if (! mv.is_null())
