@@ -4,27 +4,20 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "BoardUtil.h"
 
 #include "PentobiSgfUtil.h"
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
 #include <sstream>
 #endif
 
 namespace libpentobi_base {
-namespace boardutil {
 
 using namespace std;
-using sgf_util::get_color_id;
-using sgf_util::get_setup_id;
 
 //-----------------------------------------------------------------------------
 
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
 string dump(const Board& bd)
 {
     ostringstream s;
@@ -90,5 +83,4 @@ void write_setup(Writer& writer, Variant variant, const Setup& setup)
 
 //-----------------------------------------------------------------------------
 
-} // namespace boardutil
 } // namespace libpentobi_base
