@@ -4,20 +4,19 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifndef LIBPENTOBI_BASE_BOARDUTIL_H
-#define LIBPENTOBI_BASE_BOARDUTIL_H
+#ifndef LIBPENTOBI_BASE_BOARD_UTIL_H
+#define LIBPENTOBI_BASE_BOARD_UTIL_H
 
 #include "Board.h"
 #include "libboardgame_sgf/Writer.h"
 
 namespace libpentobi_base {
-namespace boardutil {
 
 using libboardgame_sgf::Writer;
 
 //-----------------------------------------------------------------------------
 
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
 string dump(const Board& bd);
 #endif
 
@@ -34,7 +33,6 @@ Move get_transformed(const Board& bd, Move mv,
 
 //-----------------------------------------------------------------------------
 
-} // namespace boardutil
 } // namespace libpentobi_base
 
-#endif // LIBPENTOBI_BASE_BOARDUTIL_H
+#endif // LIBPENTOBI_BASE_BOARD_UTIL_H
