@@ -8,7 +8,6 @@
 #define LIBPENTOBI_BASE_COLOR_H
 
 #include <cstdint>
-#include <iosfwd>
 #include "libboardgame_util/Assert.h"
 
 namespace libpentobi_base {
@@ -98,7 +97,7 @@ private:
 
 inline Color::Color()
 {
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
     m_i = value_uninitialized;
 #endif
 }
@@ -151,12 +150,6 @@ inline Color::IntType Color::to_int() const
 
 //-----------------------------------------------------------------------------
 
-/** Output string representation of color.
-    The strings "1", "2", ... are used for the colors. */
-ostream& operator<<(ostream& out, Color c);
-
-//-----------------------------------------------------------------------------
-
 /** Unrolled loop over all colors. */
 template<class FUNCTION>
 inline void for_each_color(FUNCTION f)
