@@ -20,7 +20,7 @@ class Game
 {
 public:
     /** Determine a sensible value for the color to play at the current node.
-        If the color was explicitely set with a setup property, it will be
+        If the color was explicitly set with a setup property, it will be
         used. Otherwise, the effective color to play will be used, starting
         with the next color of the color of the last move (see
         Board::get_effective_to_play(Color))  */
@@ -39,8 +39,7 @@ public:
         goto_node() might throw an exception.
         @param root The root node of the SGF tree; the ownership is transferred
         to this class.
-        @throws InvalidTree, if the root node contains invalid
-        properties */
+        @throws SgfError if the root node contains invalid properties */
     void init(unique_ptr<SgfNode>& root);
 
     const Board& get_board() const;
@@ -66,9 +65,9 @@ public:
     void play(Color c, Move mv, bool always_create_new_node);
 
     /** Update game state to a node in the tree.
-        @throws InvalidTree, if the game was constructed with an
+        @throws SgfError if the game was constructed with an
         external SGF tree and the tree contained invalid property values
-        (syntactically or sematically, like moves on occupied points). If an
+        (syntactically or semantically, like moves on occupied points). If an
         exception is thrown, the current node is not changed. */
     void goto_node(const SgfNode& node);
 
@@ -76,9 +75,9 @@ public:
         @pre get_tree().has_move(get_current())
         @pre get_current()->has_parent()
         @note Even if the implementation of this function calls goto_node(),
-        it cannot throw an InvalidPropertyValue because the class Game ensures
-        that the current node is always reachable via a path of nodes with
-        valid move properties. */
+        it cannot throw an InvalidProperty because the class Game ensures that
+        the current node is always reachable via a path of nodes with valid
+        move properties. */
     void undo();
 
     /** Set the current color to play.
@@ -96,23 +95,23 @@ public:
 
     void set_charset(const string& charset);
 
-    void remove_move_annotation();
+    void remove_move_annotation(const SgfNode& node);
 
-    double get_bad_move() const;
+    double get_bad_move(const SgfNode& node) const;
 
-    double get_good_move() const;
+    double get_good_move(const SgfNode& node) const;
 
-    bool is_doubtful_move() const;
+    bool is_doubtful_move(const SgfNode& node) const;
 
-    bool is_interesting_move() const;
+    bool is_interesting_move(const SgfNode& node) const;
 
-    void set_bad_move(double value = 1);
+    void set_bad_move(const SgfNode& node, double value = 1);
 
-    void set_good_move(double value = 1);
+    void set_good_move(const SgfNode& node, double value = 1);
 
-    void set_doubtful_move();
+    void set_doubtful_move(const SgfNode& node);
 
-    void set_interesting_move();
+    void set_interesting_move(const SgfNode& node);
 
     string get_comment() const;
 
@@ -140,7 +139,7 @@ public:
 
     /** Delete all variations but the main variation.
         If the current node is not in the main variation it will be changed
-        to the node as in libboardgame_sgf::util::back_to_main_variation() */
+        to the node as in libboardgame_sgf::back_to_main_variation() */
     void delete_all_variations();
 
     /** Make the current node the first child of its parent. */
@@ -209,9 +208,9 @@ inline void Game::clear_modified()
     m_tree.clear_modified();
 }
 
-inline double Game::get_bad_move() const
+inline double Game::get_bad_move(const SgfNode& node) const
 {
-    return m_tree.get_bad_move(*m_current);
+    return SgfTree::get_bad_move(node);
 }
 
 inline const Board& Game::get_board() const
@@ -239,9 +238,9 @@ inline const SgfNode& Game::get_current() const
     return *m_current;
 }
 
-inline double Game::get_good_move() const
+inline double Game::get_good_move(const SgfNode& node) const
 {
-    return m_tree.get_good_move(*m_current);
+    return SgfTree::get_good_move(node);
 }
 
 inline ColorMove Game::get_move() const
@@ -281,7 +280,7 @@ inline const PentobiTree& Game::get_tree() const
 
 inline bool Game::has_setup() const
 {
-    return libpentobi_base::node_util::has_setup(*m_current);
+    return libpentobi_base::has_setup(*m_current);
 }
 
 inline Variant Game::get_variant() const
@@ -294,14 +293,14 @@ inline void Game::init()
     init(m_bd->get_variant());
 }
 
-inline bool Game::is_doubtful_move() const
+inline bool Game::is_doubtful_move(const SgfNode& node) const
 {
-    return m_tree.is_doubtful_move(*m_current);
+    return SgfTree::is_doubtful_move(node);
 }
 
-inline bool Game::is_interesting_move() const
+inline bool Game::is_interesting_move(const SgfNode& node) const
 {
-    return m_tree.is_interesting_move(*m_current);
+    return SgfTree::is_interesting_move(node);
 }
 
 inline bool Game::is_modified() const
@@ -334,9 +333,9 @@ inline void Game::play(Color c, Move mv, bool always_create_new_node)
     play(ColorMove(c, mv), always_create_new_node);
 }
 
-inline void Game::remove_move_annotation()
+inline void Game::remove_move_annotation(const SgfNode& node)
 {
-    m_tree.remove_move_annotation(*m_current);
+    m_tree.remove_move_annotation(node);
 }
 
 inline void Game::set_application(const string& name, const string& version)
@@ -344,9 +343,9 @@ inline void Game::set_application(const string& name, const string& version)
     m_tree.set_application(name, version);
 }
 
-inline void Game::set_bad_move(double value)
+inline void Game::set_bad_move(const SgfNode& node, double value)
 {
-    m_tree.set_bad_move(*m_current, value);
+    m_tree.set_bad_move(node, value);
 }
 
 inline void Game::set_charset(const string& charset)
@@ -374,19 +373,19 @@ inline void Game::set_date_today()
     m_tree.set_date_today();
 }
 
-inline void Game::set_doubtful_move()
+inline void Game::set_doubtful_move(const SgfNode& node)
 {
-    m_tree.set_doubtful_move(*m_current);
+    m_tree.set_doubtful_move(node);
 }
 
-inline void Game::set_good_move(double value)
+inline void Game::set_good_move(const SgfNode& node, double value)
 {
-    m_tree.set_good_move(*m_current, value);
+    m_tree.set_good_move(node, value);
 }
 
-inline void Game::set_interesting_move()
+inline void Game::set_interesting_move(const SgfNode& node)
 {
-    m_tree.set_interesting_move(*m_current);
+    m_tree.set_interesting_move(node);
 }
 
 inline void Game::set_modified(bool is_modified)
