@@ -4,16 +4,11 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "PentobiSgfUtil.h"
 
 #include "libboardgame_util/Assert.h"
 
 namespace libpentobi_base {
-namespace sgf_util {
 
 //-----------------------------------------------------------------------------
 
@@ -49,5 +44,4 @@ const char* get_setup_id(Variant variant, Color c)
 
 //-----------------------------------------------------------------------------
 
-} // namespace sgf_util
 } // namespace libpentobi_base
