@@ -32,7 +32,7 @@ class PentobiTree
 public:
     /** Parse the GM property of a root node.
         @throws MissingProperty
-        @throws InvalidPropertyValue */
+        @throws InvalidProperty */
     static Variant get_variant(const SgfNode& root);
 
 
@@ -51,7 +51,7 @@ public:
     bool has_move(const SgfNode& node) const;
 
     /** Return move or ColorMove::null() if node has no move property.
-        @throws InvalidTree if the node has a move property with an invalid
+        @throws SgfError if the node has a move property with an invalid
         value. */
     ColorMove get_move(const SgfNode& node) const;
 
@@ -70,10 +70,6 @@ public:
 
     const BoardConst& get_board_const() const;
 
-    /** Check if any node in the main variation has a move.
-        Invalid move properties are ignored. */
-    bool has_main_variation_moves() const;
-
     void keep_only_subtree(const SgfNode& node);
 
     /** Add a piece as setup.
@@ -126,12 +122,12 @@ inline const BoardConst& PentobiTree::get_board_const() const
 
 inline const char* PentobiTree::get_color(Color c) const
 {
-    return sgf_util::get_color_id(m_variant, c);
+    return get_color_id(m_variant, c);
 }
 
 inline const char* PentobiTree::get_setup_prop_id(Color c) const
 {
-    return sgf_util::get_setup_id(m_variant, c);
+    return get_setup_id(m_variant, c);
 }
 
 inline Variant PentobiTree::get_variant() const
@@ -141,7 +137,7 @@ inline Variant PentobiTree::get_variant() const
 
 inline bool PentobiTree::has_move(const SgfNode& node) const
 {
-    return libpentobi_base::node_util::has_move(node, m_variant);
+    return libpentobi_base::has_move(node, m_variant);
 }
 
 inline void PentobiTree::set_move(const SgfNode& node, ColorMove mv)
@@ -153,4 +149,4 @@ inline void PentobiTree::set_move(const SgfNode& node, ColorMove mv)
 
 } // namespace libpentobi_base
 
-#endif // LIBPENTOBI_BASE_PENTOBI_SGF_TREE_H
+#endif // LIBPENTOBI_BASE_PENTOBI_TREE_H
