@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "PieceInfo.h"
 
 #include <algorithm>
@@ -43,7 +39,7 @@ struct NormalizedPoints
     }
 };
 
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
 /** Check consistency of transformations.
     Checks that the point list (which must be already sorted) has no
     duplicates. */
@@ -87,12 +83,11 @@ NormalizedPoints normalize(const PiecePoints& points, unsigned point_type,
 
 PieceInfo::PieceInfo(const string& name, const PiecePoints& points,
                      const Geometry& geo, const PieceTransforms& transforms,
-                     PieceSet piece_set, CoordPoint label_pos,
+                     GeometryType geometry_type, CoordPoint label_pos,
                      unsigned nu_instances)
     : m_nu_instances(nu_instances),
       m_points(points),
       m_label_pos(label_pos),
-      m_transforms(&transforms),
       m_name(name)
 {
     LIBBOARDGAME_ASSERT(nu_instances > 0);
@@ -103,7 +98,7 @@ PieceInfo::PieceInfo(const string& name, const PiecePoints& points,
     auto& all_transforms = transforms.get_all();
     vector<NormalizedPoints> all_transformed_points;
     all_transformed_points.reserve(all_transforms.size());
-    m_uniq_transforms.reserve(all_transforms.size()); // Upper limit
+    m_transforms.reserve(all_transforms.size()); // Upper limit
     PiecePoints transformed_points;
     for (auto transform : all_transforms)
     {
@@ -132,13 +127,13 @@ PieceInfo::PieceInfo(const string& name, const PiecePoints& points,
         else
         {
             if (log_piece_creation)
-                LIBBOARDGAME_LOG("New (", m_uniq_transforms.size(), ")");
+                LIBBOARDGAME_LOG("New (", m_transforms.size(), ")");
             m_equivalent_transform[transform] = transform;
-            m_uniq_transforms.push_back(transform);
+            m_transforms.push_back(transform);
         }
         all_transformed_points.push_back(normalized);
     }
-    if (piece_set == PieceSet::nexos)
+    if (geometry_type == GeometryType::nexos)
     {
         m_score_points = 0;
         for (auto& p : points)
@@ -149,38 +144,14 @@ PieceInfo::PieceInfo(const string& name, const PiecePoints& points,
                 ++m_score_points;
         }
     }
-    else if (piece_set == PieceSet::gembloq)
+    else if (geometry_type == GeometryType::gembloq)
         m_score_points = 0.25f * static_cast<ScoreType>(points.size());
-    else if (points.size() == 1 && piece_set == PieceSet::callisto)
+    else if (points.size() == 1 && geometry_type == GeometryType::callisto)
         m_score_points = 0;
     else
         m_score_points = static_cast<ScoreType>(points.size());
 }
 
-bool PieceInfo::can_flip_horizontally(const Transform* transform) const
-{
-    transform = get_equivalent_transform(transform);
-    auto flip = get_equivalent_transform(
-                           m_transforms->get_mirrored_horizontally(transform));
-    return flip != transform;
-}
-
-bool PieceInfo::can_flip_vertically(const Transform* transform) const
-{
-    transform = get_equivalent_transform(transform);
-    auto flip = get_equivalent_transform(
-                             m_transforms->get_mirrored_vertically(transform));
-    return flip != transform;
-}
-
-bool PieceInfo::can_rotate() const
-{
-    auto transform = m_uniq_transforms[0];
-    auto rotate = get_equivalent_transform(
-                                m_transforms->get_rotated_clockwise(transform));
-    return rotate != transform;
-}
-
 const Transform* PieceInfo::find_transform(const Geometry& geo,
                                            const Points& points) const
 {
@@ -209,8 +180,8 @@ const Transform* PieceInfo::get_equivalent_transform(
 const Transform* PieceInfo::get_next_transform(const Transform* transform) const
 {
     transform = get_equivalent_transform(transform);
-    auto begin = m_uniq_transforms.begin();
-    auto end = m_uniq_transforms.end();
+    auto begin = m_transforms.begin();
+    auto end = m_transforms.end();
     auto pos = find(begin, end, transform);
     LIBBOARDGAME_ASSERT(pos != end);
     if (pos + 1 == end)
@@ -222,8 +193,8 @@ const Transform* PieceInfo::get_previous_transform(
                                               const Transform* transform) const
 {
     transform = get_equivalent_transform(transform);
-    auto begin = m_uniq_transforms.begin();
-    auto end = m_uniq_transforms.end();
+    auto begin = m_transforms.begin();
+    auto end = m_transforms.end();
     auto pos = find(begin, end, transform);
     LIBBOARDGAME_ASSERT(pos != end);
     if (pos == begin)
