@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "PieceTransformsClassic.h"
 
 #include "libboardgame_util/Assert.h"
@@ -23,10 +19,10 @@ PieceTransformsClassic::PieceTransformsClassic()
     m_all.push_back(&m_rot90);
     m_all.push_back(&m_rot180);
     m_all.push_back(&m_rot270);
-    m_all.push_back(&m_refl);
     m_all.push_back(&m_rot90refl);
     m_all.push_back(&m_rot180refl);
     m_all.push_back(&m_rot270refl);
+    m_all.push_back(&m_refl);
 }
 
 const Transform* PieceTransformsClassic::get_mirrored_horizontally(
