@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "PieceTransformsTrigon.h"
 
 #include "libboardgame_util/Assert.h"
@@ -25,17 +21,12 @@ PieceTransformsTrigon::PieceTransformsTrigon()
     m_all.push_back(&m_rot180);
     m_all.push_back(&m_rot240);
     m_all.push_back(&m_rot300);
-    m_all.push_back(&m_refl);
     m_all.push_back(&m_refl_rot60);
     m_all.push_back(&m_refl_rot120);
     m_all.push_back(&m_refl_rot180);
     m_all.push_back(&m_refl_rot240);
     m_all.push_back(&m_refl_rot300);
-}
-
-const Transform* PieceTransformsTrigon::get_default() const
-{
-    return &m_identity;
+    m_all.push_back(&m_refl);
 }
 
 const Transform* PieceTransformsTrigon::get_mirrored_horizontally(
