@@ -4,8 +4,8 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifndef LIBPENTOBI_BASE_POINTSTATE_H
-#define LIBPENTOBI_BASE_POINTSTATE_H
+#ifndef LIBPENTOBI_BASE_POINT_STATE_H
+#define LIBPENTOBI_BASE_POINT_STATE_H
 
 #include "Color.h"
 
@@ -61,7 +61,7 @@ private:
 
 inline PointState::PointState()
 {
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
     m_i = value_uninitialized;
 #endif
 }
@@ -133,10 +133,6 @@ inline PointState::IntType PointState::to_int() const
 
 //-----------------------------------------------------------------------------
 
-ostream& operator<<(ostream& out, const PointState& s);
-
-//-----------------------------------------------------------------------------
-
 } // namespace libpentobi_base
 
-#endif // LIBPENTOBI_BASE_POINTSTATE_H
+#endif // LIBPENTOBI_BASE_POINT_STATE_H
