@@ -4,20 +4,18 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "TrigonGeometry.h"
 
+#include <map>
+#include <memory>
+
 namespace libpentobi_base {
 
+using namespace std;
 using libboardgame_base::CoordPoint;
 
 //-----------------------------------------------------------------------------
 
-map<unsigned, shared_ptr<TrigonGeometry>> TrigonGeometry::s_geometry;
-
 TrigonGeometry::TrigonGeometry(unsigned sz)
 {
     m_sz = sz;
@@ -26,6 +24,8 @@ TrigonGeometry::TrigonGeometry(unsigned sz)
 
 const TrigonGeometry& TrigonGeometry::get(unsigned sz)
 {
+    static map<unsigned, shared_ptr<TrigonGeometry>> s_geometry;
+
     auto pos = s_geometry.find(sz);
     if (pos != s_geometry.end())
         return *pos->second;
