@@ -7,14 +7,10 @@
 #ifndef LIBPENTOBI_BASE_TRIGON_GEOMETRY_H
 #define LIBPENTOBI_BASE_TRIGON_GEOMETRY_H
 
-#include <map>
-#include <memory>
 #include "Geometry.h"
 
 namespace libpentobi_base {
 
-using namespace std;
-
 //-----------------------------------------------------------------------------
 
 /** Geometry as used in the game Blokus Trigon.
@@ -39,6 +35,8 @@ public:
     static const TrigonGeometry& get(unsigned sz);
 
 
+    explicit TrigonGeometry(unsigned sz);
+
     AdjCoordList get_adj_coord(int x, int y) const override;
 
     DiagCoordList get_diag_coord(int x, int y) const override;
@@ -53,13 +51,7 @@ protected:
     bool init_is_onboard(unsigned x, unsigned y) const override;
 
 private:
-    /** Stores already created geometries by size. */
-    static map<unsigned, shared_ptr<TrigonGeometry>> s_geometry;
-
     unsigned m_sz;
-
-
-    explicit TrigonGeometry(unsigned sz);
 };
 
 //-----------------------------------------------------------------------------
