@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "Util.h"
 
 #include <thread>
@@ -17,11 +13,10 @@
 #include "libpentobi_base/PentobiSgfUtil.h"
 
 namespace libpentobi_mcts {
-namespace util {
 
 using libboardgame_sgf::Writer;
-using libpentobi_base::boardutil::write_setup;
-using libpentobi_base::sgf_util::get_color_id;
+using libpentobi_base::write_setup;
+using libpentobi_base::get_color_id;
 
 //-----------------------------------------------------------------------------
 
@@ -114,5 +109,4 @@ unsigned get_nu_threads()
 
 //-----------------------------------------------------------------------------
 
-} // namespace util
 } // namespace libpentobi_mcts
