@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "Engine.h"
 
 #include <fstream>
@@ -19,7 +15,7 @@ namespace pentobi_gtp {
 using libboardgame_gtp::Failure;
 using libboardgame_sgf::Writer;
 using libpentobi_base::Board;
-using libpentobi_base::sgf_util::get_color_id;
+using libpentobi_base::get_color_id;
 using libpentobi_mcts::Float;
 
 //-----------------------------------------------------------------------------
@@ -55,7 +51,7 @@ void Engine::cmd_move_values(Response& response)
     children.reserve(tree.get_root().get_nu_children());
     for (auto& i : tree.get_root_children())
         children.push_back(&i);
-    sort(children.begin(), children.end(), libpentobi_mcts::util::compare_node);
+    sort(children.begin(), children.end(), libpentobi_mcts::compare_node);
     response << fixed;
     for (auto node : children)
         response << setprecision(0) << node->get_visit_count() << ' '
@@ -75,7 +71,7 @@ void Engine::cmd_save_tree(Arguments args)
     if (! search.get_last_history().is_valid())
         throw Failure("no search tree");
     ofstream out(args.get());
-    libpentobi_mcts::util::dump_tree(out, search);
+    libpentobi_mcts::dump_tree(out, search);
 }
 
 /** Let the engine play a number of games against itself.
@@ -125,7 +121,6 @@ void Engine::cmd_param(Arguments args, Response& response)
     if (args.get_size() == 0)
         response
             << "avoid_symmetric_draw " << s.get_avoid_symmetric_draw() << '\n'
-            << "auto_param " << s.get_auto_param() << '\n'
             << "exploration_constant " << s.get_exploration_constant() << '\n'
             << "fixed_simulations " << p.get_fixed_simulations() << '\n'
             << "rave_child_max " << s.get_rave_child_max() << '\n'
@@ -139,8 +134,6 @@ void Engine::cmd_param(Arguments args, Response& response)
         string name = args.get(0);
         if (name == "avoid_symmetric_draw")
             s.set_avoid_symmetric_draw(args.parse<bool>(1));
-        else if (name == "auto_param")
-            s.set_auto_param(args.parse<bool>(1));
         else if (name == "exploration_constant")
             s.set_exploration_constant(args.parse<Float>(1));
         else if (name == "fixed_simulations")
@@ -170,18 +163,9 @@ void Engine::cmd_version(Response& response)
 #ifdef VERSION
     version = VERSION;
 #else
-    version = "UNKNOWN";
+    version = "unknown";
 #endif
-    // By convention, the version string of unreleased versions contains the
-    // string UNKNOWN (appended to the last released version). In this case, or
-    // if VERSION was undefined, we append the build date.
-    if (version.find("UNKNOWN") != string::npos)
-    {
-        version.append(" (");
-        version.append(__DATE__);
-        version.append(")");
-    }
-#if LIBBOARDGAME_DEBUG
+#ifdef LIBBOARDGAME_DEBUG
     version.append(" (dbg)");
 #endif
     response.set(version);
