@@ -10,6 +10,7 @@
 #include <QImage>
 #include <QImageWriter>
 #include <QString>
+#include "libboardgame_util/Log.h"
 #include "libpentobi_thumbnail/CreateThumbnail.h"
 
 using namespace std;
@@ -18,17 +19,23 @@ using namespace std;
 
 int main(int argc, char* argv[])
 {
+    libboardgame_util::LogInitializer log_initializer;
     QCoreApplication app(argc, argv);
     try
     {
         QCommandLineParser parser;
-        QCommandLineOption optionSize(QStringList() << "s" << "size",
-                    "Generate image with height and width <size>.",
-                    "size", "128");
+        QCommandLineOption optionSize(
+                    QStringList() << QStringLiteral("s")
+                    << QStringLiteral("size"),
+                    QStringLiteral(
+                        "Generate image with height and width <size>."),
+                    QStringLiteral("size"), QStringLiteral("128"));
         parser.addOption(optionSize);
         parser.addHelpOption();
-        parser.addPositionalArgument("input.blksgf", "Blokus SGF input file");
-        parser.addPositionalArgument("output.png", "PNG image output file");
+        parser.addPositionalArgument(QStringLiteral("input.blksgf"),
+                                     QStringLiteral("Blokus SGF input file"));
+        parser.addPositionalArgument(QStringLiteral("output.png"),
+                                     QStringLiteral("PNG image output file"));
         parser.process(app);
         auto args = parser.positionalArguments();
         bool ok;
@@ -42,7 +49,7 @@ int main(int argc, char* argv[])
         QImage image(size, size, QImage::Format_ARGB32);
         image.fill(Qt::transparent);
         if (! createThumbnail(args.at(0), size, size, image))
-            throw runtime_error("Thumbnail generation failed");
+            throw runtime_error("Not a valid Blokus SGF file");
         QImageWriter writer(args.at(1), "png");
         if (! writer.write(image))
             throw runtime_error(writer.errorString().toLocal8Bit().constData());
