@@ -22,13 +22,11 @@ public:
     class Failure
         : public runtime_error
     {
-    public:
-        Failure(const string& message)
-            : runtime_error(message)
-        { }
+        using runtime_error::runtime_error;
     };
 
-    GtpConnection(const string& command);
+
+    explicit GtpConnection(const string& command);
 
     ~GtpConnection();
 
