@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "TwoGtp.h"
 
 #include "libboardgame_sgf/Writer.h"
@@ -132,7 +128,8 @@ void TwoGtp::play_game(unsigned game_number)
                 resign = true;
                 break;
             }
-            mv = m_bd.from_string(response);
+            if (! m_bd.from_string(mv, response))
+                throw runtime_error("invalid move");
         }
         sgf.begin_node();
         sgf.write_property(string(1, static_cast<char>(toupper(color[0]))),
