@@ -4,17 +4,12 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "libboardgame_sgf/SgfUtil.h"
 
 #include "libboardgame_test/Test.h"
 
 using namespace std;
 using namespace libboardgame_sgf;
-using namespace libboardgame_sgf::util;
 
 //-----------------------------------------------------------------------------
 
