@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "libboardgame_sgf/TreeReader.h"
 #include "libboardgame_test/Test.h"
 #include "libpentobi_base/PentobiTree.h"
@@ -40,7 +36,7 @@ LIBBOARDGAME_TEST_CASE(pentobi_base_tree_backward_compatibility_0_1)
     {
         auto mv = tree.get_move(*node);
         LIBBOARDGAME_CHECK(! mv.is_null());
-        LIBBOARDGAME_CHECK_EQUAL(mv.color, Color(0));
+        LIBBOARDGAME_CHECK_EQUAL(mv.color.to_int(), 0u);
         auto points = bc.get_move_points(mv.move);
         LIBBOARDGAME_CHECK(points.contains(geo.get_point(0, 4)));
         LIBBOARDGAME_CHECK(points.contains(geo.get_point(0, 3)));
@@ -52,7 +48,7 @@ LIBBOARDGAME_TEST_CASE(pentobi_base_tree_backward_compatibility_0_1)
     {
         auto mv = tree.get_move(*node);
         LIBBOARDGAME_CHECK(! mv.is_null());
-        LIBBOARDGAME_CHECK_EQUAL(mv.color, Color(1));
+        LIBBOARDGAME_CHECK_EQUAL(mv.color.to_int(), 1u);
         auto points = bc.get_move_points(mv.move);
         LIBBOARDGAME_CHECK(points.contains(geo.get_point(18, 3)));
         LIBBOARDGAME_CHECK(points.contains(geo.get_point(19, 3)));
@@ -64,7 +60,7 @@ LIBBOARDGAME_TEST_CASE(pentobi_base_tree_backward_compatibility_0_1)
     {
         auto mv = tree.get_move(*node);
         LIBBOARDGAME_CHECK(! mv.is_null());
-        LIBBOARDGAME_CHECK_EQUAL(mv.color, Color(2));
+        LIBBOARDGAME_CHECK_EQUAL(mv.color.to_int(), 2u);
         auto points = bc.get_move_points(mv.move);
         LIBBOARDGAME_CHECK(points.contains(geo.get_point(19, 19)));
         LIBBOARDGAME_CHECK(points.contains(geo.get_point(19, 18)));
@@ -76,7 +72,7 @@ LIBBOARDGAME_TEST_CASE(pentobi_base_tree_backward_compatibility_0_1)
     {
         auto mv = tree.get_move(*node);
         LIBBOARDGAME_CHECK(! mv.is_null());
-        LIBBOARDGAME_CHECK_EQUAL(mv.color, Color(3));
+        LIBBOARDGAME_CHECK_EQUAL(mv.color.to_int(), 3u);
         auto points = bc.get_move_points(mv.move);
         LIBBOARDGAME_CHECK(points.contains(geo.get_point(0, 19)));
         LIBBOARDGAME_CHECK(points.contains(geo.get_point(1, 19)));
@@ -86,8 +82,8 @@ LIBBOARDGAME_TEST_CASE(pentobi_base_tree_backward_compatibility_0_1)
     }
 }
 
-/** Check that Tree constructor throws InvalidPropertyValue on unknown GM
-    property value. */
+/** Check that Tree constructor throws InvalidProperty on unknown GM property
+    value. */
 LIBBOARDGAME_TEST_CASE(pentobi_base_tree_invalid_game)
 {
     istringstream in("(;GM[1])");
