@@ -4,10 +4,6 @@
     @copyright GNU General Public License version 3 or later */
 //-----------------------------------------------------------------------------
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "libpentobi_mcts/Search.h"
 
 #include "libboardgame_sgf/SgfUtil.h"
@@ -21,7 +17,7 @@ using namespace std;
 using namespace libpentobi_mcts;
 using libboardgame_sgf::SgfNode;
 using libboardgame_sgf::TreeReader;
-using libboardgame_sgf::util::get_last_node;
+using libboardgame_sgf::get_last_node;
 using libboardgame_util::CpuTimeSource;
 using libpentobi_base::BoardUpdater;
 using libpentobi_base::PentobiTree;
